@@ -18,6 +18,7 @@
 #include <kdebug.h>
 #include <kicon.h>
 #include <klocale.h>
+#include <kwallet.h>
 
 #include "document.h"
 #include "document_p.h"
@@ -175,11 +176,26 @@ Generator::~Generator()
     delete d_ptr;
 }
 
+bool Generator::loadDocument( const QString & fileName, QVector< Page * > & pagesVector )
+{
+    return false;
+}
+
 bool Generator::loadDocumentFromData( const QByteArray &, QVector< Page * > & )
 {
     return false;
 }
 
+Document::OpenResult Generator::loadDocumentWithPassword( const QString & fileName, QVector< Page * > & pagesVector, const QString & )
+{
+    return loadDocument( fileName, pagesVector ) ? Document::OpenSuccess : Document::OpenError;
+}
+
+Document::OpenResult Generator::loadDocumentFromDataWithPassword( const QByteArray & fileData, QVector< Page * > & pagesVector, const QString & )
+{
+    return loadDocumentFromData( fileData, pagesVector ) ? Document::OpenSuccess : Document::OpenError;
+}
+
 bool Generator::closeDocument()
 {
     Q_D( Generator );
@@ -343,6 +359,13 @@ bool Generator::exportTo( const QString&, const ExportFormat& )
     return false;
 }
 
+void Generator::walletDataForFile( const QString &fileName, QString *walletName, QString *walletFolder, QString *walletKey ) const
+{
+    *walletKey = fileName.section('/', -1, -1);
+    *walletName = KWallet::Wallet::NetworkWallet();
+    *walletFolder = "KPdf";
+}
+
 bool Generator::hasFeature( GeneratorFeature feature ) const
 {
     Q_D( const Generator );
