@@ -18,6 +18,7 @@
 
 #include <kparts/part.h>
 #include <kpluginfactory.h>
+#include <kmessagewidget.h>
 #include <qicon.h>
 #include <qlist.h>
 #include <qpointer.h>
@@ -53,7 +54,6 @@ class FindBar;
 class ThumbnailList;
 class PageSizeLabel;
 class PageView;
-class PageViewTopMessage;
 class PresentationWidget;
 class ProgressWidget;
 class SearchWidget;
@@ -165,6 +165,7 @@ class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::Doc
         bool openFile();
         bool openUrl(const KUrl &url);
         void guiActivateEvent(KParts::GUIActivateEvent *event);
+        void displayInfoMessage( const QString &message, KMessageWidget::MessageType messageType = KMessageWidget::Information, int duration = -1 );;
     public:
         bool saveFile();
         bool queryClose();
@@ -228,7 +229,13 @@ class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::Doc
         void psTransformEnded(int, QProcess::ExitStatus);
         KConfigDialog * slotGeneratorPreferences();
 
+        void errorMessage( const QString &message, int duration = 0 );
+        void warningMessage( const QString &message, int duration = -1 );
+        void noticeMessage( const QString &message, int duration = -1 );
+
     private:
+        Document::OpenResult doOpenFile(const KMimeType::Ptr &mime, const QString &fileNameToOpen, bool *isCompressedFile);
+
         void setupViewerActions();
         void setViewerShortcuts();
         void setupActions();
@@ -255,8 +262,9 @@ class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::Doc
         Sidebar *m_sidebar;
         SearchWidget *m_searchWidget;
         FindBar * m_findBar;
-        PageViewTopMessage * m_topMessage;
-        PageViewTopMessage * m_formsMessage;
+        KMessageWidget * m_topMessage;
+        KMessageWidget * m_formsMessage;
+        KMessageWidget * m_infoMessage;
         QPointer<ThumbnailList> m_thumbnailList;
         QPointer<PageView> m_pageView;
         QPointer<TOC> m_toc;
@@ -337,6 +345,9 @@ class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::Doc
         KXMLGUIClient *m_generatorGuiClient;
         FileKeeper *m_keeper;
 
+        // Timer for m_infoMessage
+        QTimer *m_infoTimer;
+
     private slots:
         void slotAnnotationPreferences();
         void slotHandleActivatedSourceReference(const QString& absFileName, int line, int col, bool *handled);
